@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::TOMLParsingModules;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -8,16 +8,20 @@ our $results = [
     "OK",
     [
       {
-        dataset     => "extra-bench-typical1.toml",
-        ds_tags     => "",
-        errors      => 3.3e-06,
-        p_tags      => "",
+        errors => 3.1e-06,
+        participant => "TOML",
+        rate => 800,
+        samples => 20,
+        time => 1200,
+        vs_slowest => 1,
+      },
+      {
+        errors => 1.4e-06,
         participant => "TOML::Parser",
-        perl        => "perl",
-        rate        => 810,
-        samples     => 21,
-        time        => 1200,
-        vs_slowest  => 1,
+        rate => 820,
+        samples => 20,
+        time => 1200,
+        vs_slowest => 1,
       },
     ],
     {
@@ -120,7 +124,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "3288.300",
+                                              speed                        => 3235.746,
                                               stepping                     => 7,
                                             },
                                             {
@@ -215,7 +219,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3294.718,
+                                              speed                        => 2991.257,
                                               stepping                     => 7,
                                             },
                                             {
@@ -310,7 +314,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3291.449,
+                                              speed                        => 2280.074,
                                               stepping                     => 7,
                                             },
                                             {
@@ -405,11 +409,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3269.652,
+                                              speed                        => 2148.808,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0543439388275146,
+      "func.elapsed_time"              => 0.111171007156372,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
@@ -419,10 +423,11 @@ our $results = [
                                             "File::Slurper" => 0.008,
                                             "perl" => "v5.24.0",
                                             "Sys::Info" => 0.78,
+                                            "TOML" => 0.97,
                                             "TOML::Parser" => "0.10",
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "dataset", [0]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "jessie",
@@ -448,38 +453,16 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::TOMLParsingModules",
-      "func.scenario_module_md5sum"    => "255428656aea92128e75a7515915482d",
-      "func.scenario_module_mtime"     => 1494333946,
-      "func.scenario_module_sha1sum"   => "c9f516acb82eb6d66fb21ed9736df1ce9d5c047c",
-      "func.scenario_module_sha256sum" => "5e12586e1fbba47403b6c4515d449d86d8b6e9f41e4e9a252ccd1d38e0e83634",
-      "func.time_end"                  => 1494334096.61459,
+      "func.scenario_module_md5sum"    => "0d072188a4ffa6a7e8f051745a185a1c",
+      "func.scenario_module_mtime"     => 1494334711,
+      "func.scenario_module_sha1sum"   => "e04f5205b682aa411be9a1c7b04a22186c270148",
+      "func.scenario_module_sha256sum" => "359d8e1398dafc55bbbf330e2216fabf09080fbb4d5ed972a12eb9ac0e1dce47",
+      "func.time_end"                  => 1494338840.2042,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1494334096.56024,
-      "table.field_aligns"             => [
-                                            "left",
-                                            "left",
-                                            "left",
-                                            "left",
-                                            "left",
-                                            "number",
-                                            "number",
-                                            "number",
-                                            "number",
-                                            "number",
-                                          ],
-      "table.field_units"              => [undef, undef, undef, undef, undef, "/s", "\x{3BC}s"],
-      "table.fields"                   => [
-                                            "participant",
-                                            "dataset",
-                                            "ds_tags",
-                                            "p_tags",
-                                            "perl",
-                                            "rate",
-                                            "time",
-                                            "vs_slowest",
-                                            "errors",
-                                            "samples",
-                                          ],
+      "func.time_start"                => 1494338840.09303,
+      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
+      "table.field_units"              => [undef, "/s", "\x{3BC}s"],
+      "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
     },
   ],
 ];
